@@ -1,8 +1,9 @@
 mod common;
 
 use crate::common::with_temp_dir;
-use benchie::{append_benchmark, load_all_benchmarks, Benchmark, ExecutionResult};
+use benchie::{append_benchmark, load_all_benchmarks, Benchmark, ExecutionResult, GitInfo, Value};
 use serial_test::serial;
+use std::collections::HashMap;
 use std::fs;
 use std::fs::create_dir;
 use std::time::Duration;
@@ -25,10 +26,7 @@ fn test_with_missing_dir() {
             "should not have created a file, while reading"
         );
 
-        let result = append_benchmark(
-            &["sleep".to_string(), "1".to_string()],
-            &create_execution_result(),
-        );
+        let result = append_benchmark(&create_benchmark());
 
         assert!(result.is_ok(), "should not fail with empty dir");
         assert!(
@@ -61,10 +59,7 @@ fn test_with_existing_dir_but_missing_data() {
             "should not have created a file as a result"
         );
 
-        let result = append_benchmark(
-            &["sleep".to_string(), "1".to_string()],
-            &create_execution_result(),
-        );
+        let result = append_benchmark(&create_benchmark());
 
         assert!(result.is_ok(), "should not fail with empty dir");
         assert!(
@@ -85,8 +80,8 @@ fn test_with_existing_dir_and_data() {
 
         let benchmark = create_benchmark();
         let data = format!(
-            "{{ \"benchmarks\": [{}]}}",
-            serde_json::to_string(&benchmark).unwrap()
+            "{{ \"schema\": 1, \"benchmarks\": [{}]}}",
+            serde_json::to_string_pretty(&benchmark).unwrap()
         );
 
         let _ = fs::write(&data_file_path, data);
@@ -103,10 +98,7 @@ fn test_with_existing_dir_and_data() {
             "should be able to load pre saved benchmark"
         );
 
-        let result = append_benchmark(
-            &["sleep".to_string(), "1".to_string()],
-            &create_execution_result(),
-        );
+        let result = append_benchmark(&create_benchmark());
         assert!(result.is_ok(), "should succeed to append a benchmark");
 
         let result = load_all_benchmarks();
@@ -119,6 +111,24 @@ fn test_with_existing_dir_and_data() {
     })
 }
 
+#[test]
+#[serial]
+fn should_save_tags_in_benchmark() {
+    with_temp_dir(|_| {
+        append_benchmark(&create_benchmark()).expect("should succeed to append a benchmark");
+
+        let benchmarks = load_all_benchmarks().expect("should successfully load benchmarks");
+
+        let benchmark = benchmarks.get(0).expect("should have loaded one benchmark");
+
+        assert_eq!(
+            benchmark.data.get("key"),
+            Some(&Value::String(String::from("value"))),
+            "should have added a key=value pair"
+        );
+    })
+}
+
 fn create_execution_result() -> ExecutionResult {
     ExecutionResult {
         real_time: Duration::from_secs(1),
@@ -129,5 +139,20 @@ fn create_execution_result() -> ExecutionResult {
 fn create_benchmark() -> Benchmark {
     let result = create_execution_result();
 
-    Benchmark::new(&["ls".to_string(), "-la".to_string()], &result)
+    let info = GitInfo {
+        commit_id: "adfadsfasd".to_string(),
+        commit_message: "hello commit".to_string(),
+        branch: "master".to_string(),
+        is_dirty: false,
+    };
+
+    let mut tags = HashMap::new();
+    tags.insert(String::from("key"), String::from("value"));
+
+    Benchmark::new(
+        &["ls".to_string(), "-la".to_string()],
+        &result,
+        &Some(info),
+        &tags,
+    )
 }
